==> treemap-0.3.1.tar.gz: lib/src/treenode.dart <==
import 'package:flutter/material.dart';
import 'package:treemap/src/treenode_base.dart';

class TreeNode implements TreeNodeBase {
  List<TreeNode>? _children;
  TreeNodeOptions? options;
  EdgeInsets _margin;
  EdgeInsets? _padding;
  num _value = 0;
  WidgetBuilder? _builder;
  TreeNode? _parent;
  double top = 0;
  double left = 0;
  double right = 0;
  double bottom = 0;

  List<TreeNode>? get children => _children;
  num get value => _value;
  EdgeInsets get margin => _margin;
  EdgeInsets? get padding => _padding;
  WidgetBuilder? get builder => _builder;
  TreeNode? get parent => _parent;

  TreeNode.node({
    required List<TreeNode> children,
    EdgeInsets margin = const EdgeInsets.all(0),
    EdgeInsets padding = const EdgeInsets.all(0),
  })  : _children = children,
        _margin = margin,
        _padding = padding,
        assert(children.length > 0) {
    _value = 0;
    for (var child in children) {
      _value += child.value;
      child._parent = this;
    }
  }

  TreeNode.leaf({
    required num value,
    WidgetBuilder? builder,
    EdgeInsets margin = const EdgeInsets.all(0),
    this.options,
  })  : _value = value,
        _builder = builder,
        _margin = margin;

  int get depth {
    int depth = 0;
    TreeNode? parent = _parent;
    while (parent != null) {
      parent = parent._parent;
      depth++;
    }
    return depth;
  }

  List<TreeNode> get leaves {
    var leafs = <TreeNode>[];
    for (var child in children!) {
      if (child.children == null) {
        leafs.add(child);
      } else {
        leafs.addAll(child.leaves);
      }
    }
    return leafs;
  }

  eachBefore(Function(TreeNode) callback) {
    var node = this;
    var nodes = [node];

    while (nodes.isNotEmpty) {
      node = nodes.removeLast();
      callback(node);
      var children = node.children;
      if (children != null) {
        nodes.addAll(children);
      }
    }
  }
}

class TreeNodeOptions {
  final Color? color;
  final BoxBorder? border;
  final Widget? child;
  GestureTapCallback? onTap;

  TreeNodeOptions({
    this.color,
    this.border,
    this.child,
    this.onTap,
  });
}

==> treemap-0.3.2.tar.gz: lib/src/treenode.dart <==
import 'package:flutter/material.dart';
import 'package:treemap/src/treenode_base.dart';

class TreeNode implements TreeNodeBase {
  List<TreeNode>? children;
  TreeNodeOptions? options;
  EdgeInsets margin;
  EdgeInsets padding;
  num value = 0;
  WidgetBuilder? builder;

  TreeNode? parent;
  double top = 0;
  double left = 0;
  double right = 0;
  double bottom = 0;

  TreeNode.node({
    required this.children,
    WidgetBuilder? builder,
    this.margin = const EdgeInsets.all(0),
    this.padding = const EdgeInsets.all(0),
    this.options,
  }) : assert(children != null && children.length > 0) {
    for (var child in children ?? []) {
      this.value += child.value;
      child.parent = this;
    }
  }

  TreeNode.leaf({
    required this.value,
    WidgetBuilder? builder,
    this.margin = const EdgeInsets.all(0),
    this.padding = const EdgeInsets.all(0),
    this.options,
  }) : assert(value > 0);

  int get depth {
    int depth = 0;
    TreeNode? dparent = parent;
    while (dparent != null) {
      dparent = dparent.parent;
      depth++;
    }
    return depth;
  }

  List<TreeNode> get leaves {
    var leafs = <TreeNode>[];
    for (var child in children!) {
      if (child.children == null) {
        leafs.add(child);
      } else {
        leafs.addAll([child, ...child.leaves]);
      }
    }
    return leafs;
  }

  eachBefore(Function(TreeNode) callback) {
    var node = this;
    var nodes = [node];

    while (nodes.isNotEmpty) {
      node = nodes.removeLast();
      callback(node);
      var children = node.children;
      if (children != null) {
        nodes.addAll(children);
      }
    }
  }
}

class TreeNodeOptions {
  final Color? color;
  final BoxBorder? border;
  final Widget? child;
  GestureTapCallback? onTap;

  TreeNodeOptions({
    this.color,
    this.border,
    this.child,
    this.onTap,
  });
}
